@@ -1,20 +1,8 @@
 /*
- * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * Copyright (C) 2011-2018 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
+ * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef TEMPLATEPARSER_CUSTOMTEMPLATES_H
@@ -32,7 +20,9 @@ class Ui_CustomTemplatesBase;
 
 namespace TemplateParser {
 class CustomTemplateItem;
-
+/**
+ * @brief The CustomTemplates class
+ */
 class TEMPLATEPARSER_EXPORT CustomTemplates : public QWidget
 {
     Q_OBJECT
@@ -69,9 +59,9 @@ private Q_SLOTS:
     void slotDuplicateClicked();
 
 private:
-    bool nameAlreadyExists(const QString &str, QTreeWidgetItem *item = nullptr);
-    QString indexToType(int index);
-    QString createUniqueName(const QString &name) const;
+    Q_REQUIRED_RESULT bool nameAlreadyExists(const QString &str, QTreeWidgetItem *item = nullptr);
+    Q_REQUIRED_RESULT QString indexToType(int index);
+    Q_REQUIRED_RESULT QString createUniqueName(const QString &name) const;
     void iconFromType(CustomTemplates::Type type, CustomTemplateItem *item);
 
     /// These templates will be deleted when we're saving.
@@ -83,7 +73,7 @@ private:
 
     /// Whether or not to Q_EMIT the changed() signal. This is useful to disable when loading
     /// templates, which changes the UI without user action
-    bool mBlockChangeSignal;
+    bool mBlockChangeSignal = false;
 
     Ui_CustomTemplatesBase *mUi = nullptr;
 };
